# INCRA

[![Repo](https://img.shields.io/badge/GitHub-repo-blue?logo=github&logoColor=f5f5f5)](https://github.com/open-geodata/br_incra)

<br>

_Script_ para baixar dados do INCRA.\
Elaborado em 18.06.2021.

<br>

---

## WMS

_Site_ para exportar:

- https://certificacao.incra.gov.br/csv_shp/export_shp.py

<br>

Servidores WMS:

- http://acervofundiario.incra.gov.br/i3geo/ogc.php?tema=certificada_sigef_particular_pa
- http://acervofundiario.incra.gov.br/i3geo/ogc.php?tema=certificada_sigef_publico_pa

<br>

---

### _TODO_

1. ~~Ideal clicar em "obter" para que ele crie um arquivo novo.~~
